pub struct CreateFileSendResponse {
pub send: SendView,
pub url: String,
pub file_upload_type: FileUploadType,
pub file_id: String,
pub encrypted_file_name: String,
}Expand description
View returned after creating a file send.
Contains the created send and information needed to upload the file data.
Fields
send: SendViewThe created send.
url: StringThe upload URL for the file data.
file_upload_type: FileUploadTypeWhich upload backend the client should target with the encrypted bytes.
file_id: StringThe file ID assigned by the server.
encrypted_file_name: StringThe encrypted file name string (e.g. "2.ABCD...").